@@ -22,11 +22,11 @@ impute <- function (X, ncp = 4, scale=TRUE, method=NULL,threshold = 1e-6,seed =
    while (nb.iter > 0) {
        Xhat[missing] <- recon[missing]
        if (scale) Xhat=sweep(Xhat,2,et, FUN="*")
-       Xhat=sweep(Xhat,2,moy.p, FUN="+")
+       Xhat <- sweep(Xhat,2,moy.p, FUN="+")
        moy.p <- apply(Xhat, 2, mean,na.rm=TRUE)
        et <- apply(Xhat, 2, sd,na.rm=TRUE)
-       Xhat=sweep(Xhat,2,moy.p, FUN="-")
-       if (scale) Xhat=sweep(Xhat,2,et, FUN="/")
+       Xhat <- sweep(Xhat,2,moy.p, FUN="-")
+       if (scale) Xhat <- sweep(Xhat,2,et, FUN="/")
 
        svd.res <- svd.triplet(scale(Xhat,scale=FALSE))
        sigma2 <- mean(svd.res$vs[-(1:ncp)]^2)
